var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  categorizeCommitMessage: () => categorizeCommitMessage,
  parseCommitMessage: () => parseCommitMessage
});
module.exports = __toCommonJS(src_exports);
var COMMIT_MESSAGE_REGEX = /^(build|ci|docs|feat|fix|perf|refactor|test|chore|revert|release)(\((.*)\))?(:\s)(.*)(\r?\n+)?/;
var categorizeCommitMessage = (text) => {
  const list = text.split(/\r?\n+/);
  const others = [];
  const breakingChanges = [];
  list.forEach((item) => {
    const [, description] = item.split(/^BREAKING CHANGE:/);
    if (!description) {
      if (item.trim()) {
        others.push(item);
      }
      return;
    }
    breakingChanges.push(description.trim());
  });
  return {
    others,
    breakingChanges
  };
};
var parseCommitMessage = (commitMessage) => {
  const [firstLineCommitMessage, ...rest] = commitMessage.split(/\r?\n+/);
  const matched = firstLineCommitMessage.match(COMMIT_MESSAGE_REGEX);
  if (!matched) {
    return {
      type: "chore",
      shortSummary: commitMessage,
      firstLineFullMessage: commitMessage,
      parsed: []
    };
  }
  const [_0, type, _1, scope, _spacer, shortSummary] = matched;
  const body = rest.filter(Boolean).join("\n");
  const parsedCommitMessage = {
    type,
    shortSummary,
    firstLineFullMessage: firstLineCommitMessage,
    parsed: ["type", "short-summary", "first-line"]
  };
  if (scope) {
    parsedCommitMessage.scope = scope;
    parsedCommitMessage.parsed.push("scope");
  }
  if (body) {
    const { breakingChanges, others } = categorizeCommitMessage(body);
    if (breakingChanges.length > 0) {
      parsedCommitMessage.breakingChanges = breakingChanges;
      parsedCommitMessage.parsed.push("breaking-change");
    }
    if (others.length > 0) {
      parsedCommitMessage.body = others.join("\n");
      parsedCommitMessage.parsed.push("body");
    }
  }
  return parsedCommitMessage;
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  categorizeCommitMessage,
  parseCommitMessage
});
//# sourceMappingURL=index.cjs.map