// src/index.ts
var COMMIT_MESSAGE_REGEX = /^(build|ci|docs|feat|fix|perf|refactor|test|chore|revert|release)(\((.*)\))?(:\s)(.*)(\r?\n+)?/;
var categorizeCommitMessage = (text) => {
  const list = text.split(/\r?\n+/);
  const others = [];
  const breakingChanges = [];
  list.forEach((item) => {
    const [, description] = item.split(/^BREAKING CHANGE:/);
    if (!description) {
      if (item.trim()) {
        others.push(item);
      }
      return;
    }
    breakingChanges.push(description.trim());
  });
  return {
    others,
    breakingChanges
  };
};
var parseCommitMessage = (commitMessage) => {
  const [firstLineCommitMessage, ...rest] = commitMessage.split(/\r?\n+/);
  const matched = firstLineCommitMessage.match(COMMIT_MESSAGE_REGEX);
  if (!matched) {
    return {
      type: "chore",
      shortSummary: commitMessage,
      firstLineFullMessage: commitMessage,
      parsed: []
    };
  }
  const [_0, type, _1, scope, _spacer, shortSummary] = matched;
  const body = rest.filter(Boolean).join("\n");
  const parsedCommitMessage = {
    type,
    shortSummary,
    firstLineFullMessage: firstLineCommitMessage,
    parsed: ["type", "short-summary", "first-line"]
  };
  if (scope) {
    parsedCommitMessage.scope = scope;
    parsedCommitMessage.parsed.push("scope");
  }
  if (body) {
    const { breakingChanges, others } = categorizeCommitMessage(body);
    if (breakingChanges.length > 0) {
      parsedCommitMessage.breakingChanges = breakingChanges;
      parsedCommitMessage.parsed.push("breaking-change");
    }
    if (others.length > 0) {
      parsedCommitMessage.body = others.join("\n");
      parsedCommitMessage.parsed.push("body");
    }
  }
  return parsedCommitMessage;
};
export {
  categorizeCommitMessage,
  parseCommitMessage
};
//# sourceMappingURL=index.js.map